==> MuSE-0.7pre1.tar.gz: MuSE-0.7pre1/gtkgui/profilegui.cpp <==
/* A Gui in gtk+ for MuSE - Multiple Streaming Engine
 * Copyright (C) 2002 nightolo <night@autistici.org>
 *
 * This source code is free software; you can redistribute it and/or
 * modify it under the terms of the GNU Public License as published 
 * by the Free Software Foundation; either version 2 of the License,
 * or (at your option) any later version.
 *
 * This source code is distributed in the hope that it will be useful,
 * but WITHOUT ANY WARRANTY; without even the implied warranty of
 * MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE.
 * Please refer to the GNU Public License for more details.
 *
 * You should have received a copy of the GNU Public License along with
 * this source code; if not, write to:
 * Free Software Foundation, Inc., 675 Mass Ave, Cambridge, MA 02139, USA.
 */

#include <string.h>
#include <stdlib.h>
#include <gtk/gtk.h>
#include "../config.h"
#include "../jutils.h"
#include "generic.h"
#include "profile.h"
#include "icegui.h"
#include "lamegui.h"
#include "profilegui.h"

void profile_new(GtkWidget *w, void *tran)
{
	GtkWidget *horbox, *tmpwid;
	GtkWidget *verbbox, *listu;
	GtkWidget *load, *remove, *close, *defau;
	char *pnam[10][1];
	char title[20];
	char *type;
	int lam=0;
	unsigned int count=0;
	struct lamedata *l = NULL;
	struct icedata *i = NULL;
	
	if(winprof) 
		return;

	type= (char *) gtk_object_get_data(GTK_OBJECT(w), "type");
	snprintf(title, sizeof(title), "Manage %s", type);

	lam=strcmp(type, "lame");
	
	if(!lam) {
		l = (struct lamedata *) tran;
		l->riga=-1;
	}
	else {
		i = (struct icedata *) tran;
		i->riga=-1;
	}
	
	winprof=gtk_window_new(GTK_WINDOW_TOPLEVEL);
	gtk_window_set_title(GTK_WINDOW(winprof), title);
	gtk_container_set_border_width(GTK_CONTAINER(winprof), 5);
	gtk_signal_connect(GTK_OBJECT(winprof), "delete_event",
			(GtkSignalFunc) profile_close, NULL);
	
	horbox=gtk_hbox_new(FALSE, 5);
	gtk_container_add(GTK_CONTAINER(winprof), horbox);

	
	listu=gtk_clist_new(1);
	if(!lam) l->lista=listu; else i->lista=listu;
	gtk_widget_set_usize(listu, 70, 140);
	gtk_clist_set_column_width(GTK_CLIST(listu), 0, 90);
	
	profile_get_profile(type, pnam[0]);
	for(count=0; pnam[count][0] != NULL; count++)
		gtk_clist_append(GTK_CLIST(listu), pnam[count]);

	profile_free_pnam(pnam[0]);

	/* FIXME: unselect_row */
	if(!lam) 
		gtk_signal_connect(GTK_OBJECT(listu), "select_row",
				(GtkSignalFunc) gcb_lame_get, l);
	else
		gtk_signal_connect(GTK_OBJECT(listu), "select_row",
				(GtkSignalFunc) gcb_ice_get, i);
	
	gtk_box_pack_start(GTK_BOX(horbox), listu, FALSE, FALSE, 0);
	
	tmpwid=gtk_vseparator_new();
	gtk_box_pack_start(GTK_BOX(horbox), tmpwid, FALSE, FALSE, 0);

	verbbox=gtk_vbox_new(TRUE, 5);
	gtk_box_pack_start(GTK_BOX(horbox), verbbox, FALSE, FALSE, 0);

	load=gtk_button_new_with_label("Load");
	remove=gtk_button_new_with_label("Delete");
	close=gtk_button_new_with_label("Close");
	defau=gtk_check_button_new_with_label("default");
	
	if(!lam) {
		gtk_signal_connect(GTK_OBJECT(load), "clicked",
				(GtkSignalFunc) gcb_lame_put, l);
		gtk_signal_connect(GTK_OBJECT(remove), "clicked",
				(GtkSignalFunc) gcb_lame_rem, l);
		gtk_signal_connect(GTK_OBJECT(defau), "clicked",
				(GtkSignalFunc) gcb_lame_default, l);
	}
	else {
		gtk_signal_connect(GTK_OBJECT(load), "clicked",
				(GtkSignalFunc) gcb_ice_put, i);
		gtk_signal_connect(GTK_OBJECT(remove), "clicked",
				(GtkSignalFunc) gcb_ice_rem, i);
		gtk_signal_connect(GTK_OBJECT(defau), "clicked",
				(GtkSignalFunc) gcb_ice_default, i);
	}

	gtk_signal_connect_object(GTK_OBJECT(close), "clicked",
			(GtkSignalFunc) profile_close, GTK_OBJECT(winprof));
	
	gtk_box_pack_start(GTK_BOX(verbbox), load, FALSE, FALSE, 0);
	gtk_box_pack_start(GTK_BOX(verbbox), remove, FALSE, FALSE, 0);
	gtk_box_pack_start(GTK_BOX(verbbox), close, FALSE, FALSE, 0);
	gtk_box_pack_start(GTK_BOX(verbbox), defau, FALSE, FALSE, 0);
	
	gtk_widget_show_all(winprof);
	
}

void profile_save(GtkWidget *w, void *tran)
{
	GtkWidget *winzi, *combo, *tmpwid, *verbox;
	char *type, *pnam[10];
	GList *lst=NULL;
	unsigned int c;
	int lam=0;
	struct icedata *i;
	struct lamedata *l;
	
	type = (char *) gtk_object_get_data(GTK_OBJECT(w), "type");

	lam=strcmp(type, "lame");

	if(!lam) {
		func("profile_save:: mmm it seems lame");
		l= (struct lamedata *) tran; 
		lame_get(l);
	} else {
		func("profile_save:: mmm it seems icecast");
		i= (struct icedata *) tran;
		ice_get(i);
	}
	
	winzi=gtk_window_new(GTK_WINDOW_TOPLEVEL);
	gtk_window_set_title(GTK_WINDOW(winzi), "Save profile");
	gtk_container_set_border_width(GTK_CONTAINER(winzi), 7);
	gtk_signal_connect(GTK_OBJECT(winzi), "delete_event",
			(GtkSignalFunc) gtk_widget_destroy, NULL);
	
	verbox=gtk_vbox_new(FALSE, 5);
	gtk_container_add(GTK_CONTAINER(winzi), verbox);
	
	tmpwid=gtk_label_new("Insert or Select name");
	gtk_box_pack_start(GTK_BOX(verbox), tmpwid, FALSE, FALSE, 0);

	combo=gtk_combo_new();
	gtk_entry_set_max_length(GTK_ENTRY(GTK_COMBO(combo)->entry), 10);
	gtk_box_pack_start(GTK_BOX(verbox), combo, FALSE, FALSE, 0);
	
	if(!lam)
		profile_get_profile("lame", pnam);
	else
		profile_get_profile("icecast", pnam);

	for(c=0; c < 10; c++)
		lst=g_list_append(lst, (void *) pnam[c]);

	gtk_combo_set_popdown_strings(GTK_COMBO(combo), lst);
	gtk_entry_set_text(GTK_ENTRY(GTK_COMBO(combo)->entry), "");

	g_list_free(lst);
	profile_free_pnam(pnam);

	tmpwid=gtk_button_new_with_label("  Save  ");
	gtk_object_set_data(GTK_OBJECT(tmpwid), "window", (void *) winzi);
	
	if(!lam)
		gtk_signal_connect(GTK_OBJECT(tmpwid), "clicked",
				(GtkSignalFunc) gcb_lame_save, combo);
	else
		gtk_signal_connect(GTK_OBJECT(tmpwid), "clicked",
				(GtkSignalFunc) gcb_ice_save, combo);
		
	gtk_box_pack_start(GTK_BOX(verbox), tmpwid, FALSE, FALSE, 0);

	gtk_widget_show_all(winzi);
}

void profile_close(GtkWidget *w)
{
	gtk_widget_destroy(winprof);
	winprof=NULL;
}

==> MuSE-0.7.2.tar.gz: MuSE-0.7.2/gtkgui/profilegui.cpp <==
/* A Gui in gtk+ for MuSE - Multiple Streaming Engine
 * Copyright (C) 2002 nightolo <night@autistici.org>
 *
 * This source code is free software; you can redistribute it and/or
 * modify it under the terms of the GNU Public License as published 
 * by the Free Software Foundation; either version 2 of the License,
 * or (at your option) any later version.
 *
 * This source code is distributed in the hope that it will be useful,
 * but WITHOUT ANY WARRANTY; without even the implied warranty of
 * MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE.
 * Please refer to the GNU Public License for more details.
 *
 * You should have received a copy of the GNU Public License along with
 * this source code; if not, write to:
 * Free Software Foundation, Inc., 675 Mass Ave, Cambridge, MA 02139, USA.
 */

#include <string.h>
#include <stdlib.h>
#include <gtk/gtk.h>
#include "generic.h"
#include <icegui.h>
#include <lamegui.h>
#include <profilegui.h>

#include <jmixer.h>
#include <jutils.h>

#include <config.h>

char *sav1=NULL;
char *sav2=NULL;

void profile_new(GtkWidget *w, void *tran)
{
	GtkWidget *horbox, *tmpwid;
	GtkWidget *verbbox, *listu;
	GtkWidget *load, *remove, *close, *defau;
	char *listprof, *aprof;
	char title[20];
	char *type;
	int lam=0;
	struct lamedata *l = NULL;
	struct icedata *i = NULL;
	
	if(winprof) 
		return;

	listprof= (char *) malloc(MAX_SECTION_SIZE);
	aprof= (char *) malloc(MAX_SECTION_SIZE);
	sav1=listprof;
	sav2=aprof;
	
	type= (char *) gtk_object_get_data(GTK_OBJECT(w), "type");
	snprintf(title, sizeof(title), "Manage %s", type);

	lam=strcmp(type, "lame");

	if(!lam) {
		l = (struct lamedata *) tran;
		l->riga=-1;
		mixer->lame.list_profiles(listprof);
	}
	else {
		i = (struct icedata *) tran;
		i->riga=-1;
		mixer->ice.list_profiles(listprof);
	}
	
	winprof=gtk_window_new(GTK_WINDOW_TOPLEVEL);
	gtk_window_set_title(GTK_WINDOW(winprof), title);
	gtk_container_set_border_width(GTK_CONTAINER(winprof), 5);
	gtk_signal_connect(GTK_OBJECT(winprof), "delete_event",
			(GtkSignalFunc) profile_close, NULL);
	
	horbox=gtk_hbox_new(FALSE, 5);
	gtk_container_add(GTK_CONTAINER(winprof), horbox);

	
	listu=gtk_clist_new(1);
	if(!lam) l->lista=listu; else i->lista=listu;
	gtk_widget_set_usize(listu, 70, 140);
	gtk_clist_set_column_width(GTK_CLIST(listu), 0, 90);

	/* append value in browser */
	while((aprof=strsep(&listprof, ":")))
		if(strcmp(aprof, "last_active"))
			gtk_clist_append(GTK_CLIST(listu), &aprof);

	/* FIXME: unselect_row */
	if(!lam) 
		gtk_signal_connect(GTK_OBJECT(listu), "select_row",
				(GtkSignalFunc) gcb_lame_get, l);
	else
		gtk_signal_connect(GTK_OBJECT(listu), "select_row",
				(GtkSignalFunc) gcb_ice_get, i);
	
	gtk_box_pack_start(GTK_BOX(horbox), listu, FALSE, FALSE, 0);
	
	tmpwid=gtk_vseparator_new();
	gtk_box_pack_start(GTK_BOX(horbox), tmpwid, FALSE, FALSE, 0);

	verbbox=gtk_vbox_new(TRUE, 5);
	gtk_box_pack_start(GTK_BOX(horbox), verbbox, FALSE, FALSE, 0);

	load=gtk_button_new_with_label("Load");
	remove=gtk_button_new_with_label("Delete");
	close=gtk_button_new_with_label("Close");
	defau=gtk_check_button_new_with_label("default");
	
	if(!lam) {
		gtk_signal_connect(GTK_OBJECT(load), "clicked",
				(GtkSignalFunc) gcb_lame_put, l);
	/*	gtk_signal_connect(GTK_OBJECT(remove), "clicked",
				(GtkSignalFunc) gcb_lame_rem, l);*/
		gtk_signal_connect(GTK_OBJECT(defau), "clicked",
				(GtkSignalFunc) gcb_lame_default, l);
	}
	else {
		gtk_signal_connect(GTK_OBJECT(load), "clicked",
				(GtkSignalFunc) gcb_ice_put, i);
/*		gtk_signal_connect(GTK_OBJECT(remove), "clicked",
				(GtkSignalFunc) gcb_ice_rem, i);*/
		gtk_signal_connect(GTK_OBJECT(defau), "clicked",
				(GtkSignalFunc) gcb_ice_default, i);
	}

	gtk_signal_connect_object(GTK_OBJECT(close), "clicked",
			(GtkSignalFunc) profile_close, GTK_OBJECT(winprof));
	
	gtk_box_pack_start(GTK_BOX(verbbox), load, FALSE, FALSE, 0);
	gtk_box_pack_start(GTK_BOX(verbbox), remove, FALSE, FALSE, 0);
	gtk_box_pack_start(GTK_BOX(verbbox), close, FALSE, FALSE, 0);
	gtk_box_pack_start(GTK_BOX(verbbox), defau, FALSE, FALSE, 0);
	
	gtk_widget_show_all(winprof);
	
}

void profile_save(GtkWidget *w, void *tran)
{
	GtkWidget *winzi, *combo, *tmpwid, *verbox;
	char *type;
	char *listprof, *aprof;
	GList *lst=NULL;
	int lam=0;
	struct icedata *i;
	struct lamedata *l;
	
	
	listprof= (char *) malloc(MAX_SECTION_SIZE);
	aprof= (char *) malloc(MAX_SECTION_SIZE);
	
	type = (char *) gtk_object_get_data(GTK_OBJECT(w), "type");

	lam=strcmp(type, "lame");

	if(!lam) {
		func("profile_save:: mmm it seems lame");
		l= (struct lamedata *) tran; 
		lame_get(l);
		mixer->lame.list_profiles(listprof);
	} else {
		func("profile_save:: mmm it seems icecast");
		i= (struct icedata *) tran;
		ice_get(i);
		mixer->ice.list_profiles(listprof);
	}
	
	winzi=gtk_window_new(GTK_WINDOW_TOPLEVEL);
	gtk_window_set_title(GTK_WINDOW(winzi), "Save profile");
	gtk_container_set_border_width(GTK_CONTAINER(winzi), 7);
	gtk_signal_connect(GTK_OBJECT(winzi), "delete_event",
			(GtkSignalFunc) gtk_widget_destroy, NULL);
	
	verbox=gtk_vbox_new(FALSE, 5);
	gtk_container_add(GTK_CONTAINER(winzi), verbox);
	
	tmpwid=gtk_label_new("Insert or Select name");
	gtk_box_pack_start(GTK_BOX(verbox), tmpwid, FALSE, FALSE, 0);

	combo=gtk_combo_new();
	gtk_entry_set_max_length(GTK_ENTRY(GTK_COMBO(combo)->entry), 10);
	gtk_box_pack_start(GTK_BOX(verbox), combo, FALSE, FALSE, 0);

	while((aprof=strsep(&listprof, ":")))
		if(strcmp(aprof, "last_active"))
			lst=g_list_append(lst,(void *) aprof);

	gtk_combo_set_popdown_strings(GTK_COMBO(combo), lst);
	gtk_entry_set_text(GTK_ENTRY(GTK_COMBO(combo)->entry), "");

	g_list_free(lst);

	tmpwid=gtk_button_new_with_label("  Save  ");
	gtk_object_set_data(GTK_OBJECT(tmpwid), "window", (void *) winzi);
	
	if(!lam)
		gtk_signal_connect(GTK_OBJECT(tmpwid), "clicked",
				(GtkSignalFunc) gcb_lame_save, combo);
	else
		gtk_signal_connect(GTK_OBJECT(tmpwid), "clicked",
				(GtkSignalFunc) gcb_ice_save, combo);
		
	gtk_box_pack_start(GTK_BOX(verbox), tmpwid, FALSE, FALSE, 0);

	gtk_widget_show_all(winzi);
}

void profile_close(GtkWidget *w)
{
	gtk_widget_destroy(winprof);
	winprof=NULL;
	free(sav1);
	free(sav2);
}
